Documentation
¶
Overview ¶
jsonstore implements a JSON file based store for resumable uploads via github.com/eventials/go-tus
Locking is used to ensure concurrent access within the same JsonStore is safe, however using the same underlying JSON file for more than one JsonStore may cause data loss or corruption.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewJsonStore ¶
NewJsonStore creates a new *JsonStore using the provided file path
Types ¶
Click to show internal directories.
Click to hide internal directories.